==> mingw-w64-python-fastapi-0.110.2-1.src.tar.zst: fastapi-0.110.2/docs/em/docs/tutorial/extra-data-types.md <==
# ➕ 💽 🆎

🆙 🔜, 👆 ✔️ ⚙️ ⚠ 📊 🆎, 💖:

* `int`
* `float`
* `str`
* `bool`

✋️ 👆 💪 ⚙️ 🌅 🏗 📊 🆎.

&amp; 👆 🔜 ✔️ 🎏 ⚒ 👀 🆙 🔜:

* 👑 👨‍🎨 🐕‍🦺.
* 💽 🛠️ ⚪️➡️ 📨 📨.
* 💽 🛠️ 📨 💽.
* 💽 🔬.
* 🏧 ✍ &amp; 🧾.

## 🎏 💽 🆎

📥 🌖 📊 🆎 👆 💪 ⚙️:

* `UUID`:
    * 🐩 "⭐ 😍 🆔", ⚠ 🆔 📚 💽 &amp; ⚙️.
    * 📨 &amp; 📨 🔜 🎨 `str`.
* `datetime.datetime`:
    * 🐍 `datetime.datetime`.
    * 📨 &amp; 📨 🔜 🎨 `str` 💾 8️⃣6️⃣0️⃣1️⃣ 📁, 💖: `2008-09-15T15:53:00+05:00`.
* `datetime.date`:
    * 🐍 `datetime.date`.
    * 📨 &amp; 📨 🔜 🎨 `str` 💾 8️⃣6️⃣0️⃣1️⃣ 📁, 💖: `2008-09-15`.
* `datetime.time`:
    * 🐍 `datetime.time`.
    * 📨 &amp; 📨 🔜 🎨 `str` 💾 8️⃣6️⃣0️⃣1️⃣ 📁, 💖: `14:23:55.003`.
* `datetime.timedelta`:
    * 🐍 `datetime.timedelta`.
    * 📨 &amp; 📨 🔜 🎨 `float` 🌐 🥈.
    * Pydantic ✔ 🎦 ⚫️ "💾 8️⃣6️⃣0️⃣1️⃣ 🕰 ➕ 🔢", <a href="https://docs.pydantic.dev/latest/concepts/serialization/#json_encoders" class="external-link" target="_blank">👀 🩺 🌅 ℹ</a>.
* `frozenset`:
    * 📨 &amp; 📨, 😥 🎏 `set`:
        * 📨, 📇 🔜 ✍, ❎ ❎ &amp; 🏭 ⚫️ `set`.
        * 📨, `set` 🔜 🗜 `list`.
        * 🏗 🔗 🔜 ✔ 👈 `set` 💲 😍 (⚙️ 🎻 🔗 `uniqueItems`).
* `bytes`:
    * 🐩 🐍 `bytes`.
    * 📨 &amp; 📨 🔜 😥 `str`.
    * 🏗 🔗 🔜 ✔ 👈 ⚫️ `str` ⏮️ `binary` "📁".
* `Decimal`:
    * 🐩 🐍 `Decimal`.
    * 📨 &amp; 📨, 🍵 🎏 `float`.
* 👆 💪 ✅ 🌐 ☑ Pydantic 📊 🆎 📥: <a href="https://docs.pydantic.dev/latest/concepts/types/" class="external-link" target="_blank">Pydantic 📊 🆎</a>.

## 🖼

📥 🖼 *➡ 🛠️* ⏮️ 🔢 ⚙️ 🔛 🆎.

=== "🐍 3️⃣.6️⃣ &amp; 🔛"

    ```Python hl_lines="1  3  12-16"
    {!> ../../../docs_src/extra_data_types/tutorial001.py!}
    ```

=== "🐍 3️⃣.1️⃣0️⃣ &amp; 🔛"

    ```Python hl_lines="1  2  11-15"
    {!> ../../../docs_src/extra_data_types/tutorial001_py310.py!}
    ```

🗒 👈 🔢 🔘 🔢 ✔️ 👫 🐠 💽 🆎, &amp; 👆 💪, 🖼, 🎭 😐 📅 🎭, 💖:

=== "🐍 3️⃣.6️⃣ &amp; 🔛"

    ```Python hl_lines="18-19"
    {!> ../../../docs_src/extra_data_types/tutorial001.py!}
    ```

=== "🐍 3️⃣.1️⃣0️⃣ &amp; 🔛"

    ```Python hl_lines="17-18"
    {!> ../../../docs_src/extra_data_types/tutorial001_py310.py!}
    ```

==> mingw-w64-python-fastapi-0.115.0-1.src.tar.zst: fastapi-0.115.0/docs/em/docs/tutorial/extra-data-types.md <==
# ➕ 💽 🆎

🆙 🔜, 👆 ✔️ ⚙️ ⚠ 📊 🆎, 💖:

* `int`
* `float`
* `str`
* `bool`

✋️ 👆 💪 ⚙️ 🌅 🏗 📊 🆎.

&amp; 👆 🔜 ✔️ 🎏 ⚒ 👀 🆙 🔜:

* 👑 👨‍🎨 🐕‍🦺.
* 💽 🛠️ ⚪️➡️ 📨 📨.
* 💽 🛠️ 📨 💽.
* 💽 🔬.
* 🏧 ✍ &amp; 🧾.

## 🎏 💽 🆎

📥 🌖 📊 🆎 👆 💪 ⚙️:

* `UUID`:
    * 🐩 "⭐ 😍 🆔", ⚠ 🆔 📚 💽 &amp; ⚙️.
    * 📨 &amp; 📨 🔜 🎨 `str`.
* `datetime.datetime`:
    * 🐍 `datetime.datetime`.
    * 📨 &amp; 📨 🔜 🎨 `str` 💾 8️⃣6️⃣0️⃣1️⃣ 📁, 💖: `2008-09-15T15:53:00+05:00`.
* `datetime.date`:
    * 🐍 `datetime.date`.
    * 📨 &amp; 📨 🔜 🎨 `str` 💾 8️⃣6️⃣0️⃣1️⃣ 📁, 💖: `2008-09-15`.
* `datetime.time`:
    * 🐍 `datetime.time`.
    * 📨 &amp; 📨 🔜 🎨 `str` 💾 8️⃣6️⃣0️⃣1️⃣ 📁, 💖: `14:23:55.003`.
* `datetime.timedelta`:
    * 🐍 `datetime.timedelta`.
    * 📨 &amp; 📨 🔜 🎨 `float` 🌐 🥈.
    * Pydantic ✔ 🎦 ⚫️ "💾 8️⃣6️⃣0️⃣1️⃣ 🕰 ➕ 🔢", <a href="https://docs.pydantic.dev/latest/concepts/serialization/#json_encoders" class="external-link" target="_blank">👀 🩺 🌅 ℹ</a>.
* `frozenset`:
    * 📨 &amp; 📨, 😥 🎏 `set`:
        * 📨, 📇 🔜 ✍, ❎ ❎ &amp; 🏭 ⚫️ `set`.
        * 📨, `set` 🔜 🗜 `list`.
        * 🏗 🔗 🔜 ✔ 👈 `set` 💲 😍 (⚙️ 🎻 🔗 `uniqueItems`).
* `bytes`:
    * 🐩 🐍 `bytes`.
    * 📨 &amp; 📨 🔜 😥 `str`.
    * 🏗 🔗 🔜 ✔ 👈 ⚫️ `str` ⏮️ `binary` "📁".
* `Decimal`:
    * 🐩 🐍 `Decimal`.
    * 📨 &amp; 📨, 🍵 🎏 `float`.
* 👆 💪 ✅ 🌐 ☑ Pydantic 📊 🆎 📥: <a href="https://docs.pydantic.dev/latest/concepts/types/" class="external-link" target="_blank">Pydantic 📊 🆎</a>.

## 🖼

📥 🖼 *➡ 🛠️* ⏮️ 🔢 ⚙️ 🔛 🆎.

//// tab | 🐍 3️⃣.6️⃣ &amp; 🔛

```Python hl_lines="1  3  12-16"
{!> ../../../docs_src/extra_data_types/tutorial001.py!}
```

////

//// tab | 🐍 3️⃣.1️⃣0️⃣ &amp; 🔛

```Python hl_lines="1  2  11-15"
{!> ../../../docs_src/extra_data_types/tutorial001_py310.py!}
```

////

🗒 👈 🔢 🔘 🔢 ✔️ 👫 🐠 💽 🆎, &amp; 👆 💪, 🖼, 🎭 😐 📅 🎭, 💖:

//// tab | 🐍 3️⃣.6️⃣ &amp; 🔛

```Python hl_lines="18-19"
{!> ../../../docs_src/extra_data_types/tutorial001.py!}
```

////

//// tab | 🐍 3️⃣.1️⃣0️⃣ &amp; 🔛

```Python hl_lines="17-18"
{!> ../../../docs_src/extra_data_types/tutorial001_py310.py!}
```

////
